Fix sample 11_texture_driver for hip-clang (#1370)
[ROCm/hip commit: c404312ffe]
Cette révision appartient à :
révisé par
Maneesh Gupta
Parent
8aca7f3e25
révision
a795928420
@@ -21,7 +21,12 @@ THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include "hip/hip_runtime.h"
|
||||
extern texture<float, 2, hipReadModeElementType> tex;
|
||||
#if __HIP__
|
||||
__hip_pinned_shadow__
|
||||
#else
|
||||
extern
|
||||
#endif
|
||||
texture<float, 2, hipReadModeElementType> tex;
|
||||
|
||||
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
|
||||
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
||||
|
||||
Référencer dans un nouveau ticket
Bloquer un utilisateur